@@ -1,6 +1,6 @@
 # prime/engine/engine-basic-multiclauses.rb:
 #     Basic Engine with a Function for Multiple Clauses
-# $Id: engine-basic-multiclauses.rb,v 1.1.2.2 2003/12/28 03:00:40 komatsu Exp $
+# $Id: engine-basic-multiclauses.rb,v 1.1.2.5 2004/01/02 04:23:07 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -53,22 +53,27 @@ class PrimeEngineBasicMultipleClauses < PrimeEngineBasic
       '̾'   => ['', 'ư첽', '̾', '()&̾'],
       '()&̾' =>
                   ['', 'ư첽', '̾', '()&̾'],
+
       '̾&̾'   => ['', 'ư첽'],
+      '̾'        => ['', 'ư첽'],
+      '̾'        => ['', 'ư첽'],
 
       'ư::Ϣi' => ['ư'],
-      '' => ['ƻ', 'ư'],
-      'ƻ::Ϣ' => ['̾', '̾&̾'],
-      'ư::Ϣ' => ['̾', '̾&̾'],
-      'ư' => ['̾', '̾&̾'],
+      '' => ['ƻ', 'ư', 'ư&̾', 'ư'],
+      'ƻ::Ϣ'   => ['̾', '̾&̾', '̾', '̾'],
+      'ƻ::Ϣku' => ['ƻ'],
+      'ư::Ϣ' => ['̾', '̾&̾', '̾', '̾'],
+      'ư' => ['̾', '̾&̾', '̾', '̾'],
 
       '֤::Ϣde' => ['ư'],
-      '' => ['̾', '̾&̾', 'ư'],
+      '' => ['̾', '̾&̾', '̾', '̾', 'ư', 'ư&̾'],
     }
     @pos_connection_cost = {
 #      "Ƭ\t̾" => 0.8,
 #      "Ƭ\t()&̾" => 0.8,
 #      "̾\t" => 0.8,
       "̾&̾\t=" => 0.99,
+      "̾\t="      => 0.99,
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
       "=\t̾" => 0.99,
@@ -82,6 +87,10 @@ class PrimeEngineBasicMultipleClauses < PrimeEngineBasic
       "̾\tư첽" => 'ư',
       "̾&̾\t" => '̾',
       "̾&̾\tư첽" => 'ư',
+      "̾\t" => '̾',
+      "̾\tư첽" => 'ư',
+      "̾\t" => '̾',
+      "̾\tư첽" => 'ư',
     }      
   end
 
@@ -113,7 +122,8 @@ class PrimeEngineBasicMultipleClauses < PrimeEngineBasic
 	    if pos2 then
 	      suffix = suffix2
 
-	      result2 = lookup_dict([format("%s\t%s", base2, pos2)])
+              key = format("%s\t%s", base2, pos2)
+	      result2 = lookup_dict([key])
 	      (pron2, literal2, priority2, pos2) = parse_result(result2[0])
 
 	      connection_key = [pos, pos2].join("\t")
