@@ -1,5 +1,5 @@
 # prime/engine/engine-basic.rb
-# $Id: engine-userdict.rb,v 1.8.2.5 2003/12/29 09:50:35 komatsu Exp $
+# $Id: engine-userdict.rb,v 1.8.2.8 2004/01/15 02:38:36 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -106,17 +106,11 @@ class PrimeEngineUserdict < PrimeEngineJapanese
     @id   = "userdict"
     @description = "Userdict engine"
 
-    @partdict_file = File::join2(PRIME_USER_DIR, USERDICT + '-pos')
-    @partdict      = PrimeUserDict.new(@partdict_file)
-
-    @dict_file    = File::join2(PRIME_USER_DIR, USERDICT)
-    @dict         = PrimeUserDict.new(@dict_file, '_pron')
-    @dict_literal = PrimeUserDict.new(@dict_file, '_literal')
-    @dict_index   = PrimeUserDict.new(@dict_file, '_index')
-
-    @contextdict_file = File::join2(PRIME_USER_DIR, USERDICT + '-co')
-    @contextdict = PrimeUserDict.new(@contextdict_file, '_pron')
+    @dict_file        = File::join2(PRIME_USER_DIR, USERDICT)
+    @partdict_file    = @dict_file + '-pos'
+    @contextdict_file = @dict_file + '-co'
 
+    initialize_userdict()
     initialize_timestamp()
     initialize_priority()
     initialize_dictbuffer()
@@ -132,18 +126,25 @@ class PrimeEngineUserdict < PrimeEngineJapanese
     @last_context_index   = nil
   end
 
+  def initialize_userdict ()
+    @dict         = PrimeUserDict.new(@dict_file, '_pron')
+    @dict_literal = PrimeUserDict.new(@dict_file, '_literal')
+    @dict_index   = PrimeUserDict.new(@dict_file, '_index')
+    @partdict     = PrimeUserDict.new(@partdict_file)
+    @contextdict  = PrimeUserDict.new(@contextdict_file, '_pron')
+  end
+
   def initialize_timestamp
     @timestamps = []
-    filename = File::join2(PRIME_USER_DIR, USERDICT + '-ts')
-    if File::file?(filename) then
-      io = Kernel::open(filename, "r")
+    @filename_timestamps = File::join2(PRIME_USER_DIR, USERDICT + '-ts')
+    File::ensure(@filename_timestamps)
+    File::open(@filename_timestamps, "r") {|io|
       string = io.read()
       data_size = string.length / 4
       data_size.times{|i|
-	@timestamps[i] = string[i*4,4].unpack('N').first
+        @timestamps[i] = string[i*4,4].unpack('N').first
       }
-      io.close()
-    end
+    }
   end
 
   def initialize_priority
@@ -172,6 +173,12 @@ class PrimeEngineUserdict < PrimeEngineJapanese
 
   # ---------------------------------------- End of intialization.
 
+  def refresh ()
+    initialize_userdict()
+    initialize_timestamp()
+    return true
+  end
+
   def learn_word (pron, literal, pos, context, suffix, rest)
     if pos == "ü" then
       dictbuffer_flush()
@@ -219,7 +226,8 @@ class PrimeEngineUserdict < PrimeEngineJapanese
       index_no = indexes[0] # The number of indexes must be one.
     end
     learn_cooccurrence(pron, literal, index_no, context_index)
-    @timestamps[index_no] = timestamp
+
+    set_timestamp(index_no, timestamp)
 
     if logging == :logging then
       @logbuffer += [index_no, pron, pos, literal, timestamp].join("\t") + "\n"
@@ -228,6 +236,16 @@ class PrimeEngineUserdict < PrimeEngineJapanese
     return index_no
   end
 
+  def set_timestamp(index_no, timestamp)
+    @timestamps[index_no] = timestamp
+    unless $PRIME_NO_SAVE then
+      File::open(@filename_timestamps, "r+") {|io|
+        io.seek(index_no * 4)
+        io.write([timestamp].pack('N'))
+      }
+    end
+  end
+
   def get_index_no ()
     index_no = nil
     if $PRIME_NO_SAVE then
