@@ -1,5 +1,5 @@
 # dictformat-cannadic.rb: Converter module for cannadic format.
-# $Id: $
+# $Id: dictformat-cannadic.rb,v 1.1.2.2 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -14,8 +14,8 @@ $KCODE = 'e'
 
 class DictFormatCannadic < DictFormat
   
-  def initialize (filename_postable = nil)
-    super()
+  def initialize (is_interactive = true, filename_postable = nil)
+    super(is_interactive)
     filename_postable = (filename_postable or
                            PRIME_DATA_DIR + "/makedict/canna2prime.table")
     @pos_table = {}
