@@ -1,5 +1,5 @@
 # dictformat-skk.rb: Converter module for skk format.
-# $Id: $
+# $Id: dictformat-skkdic.rb,v 1.1.2.2 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -12,8 +12,8 @@ require 'prime/makedict/dictformat'
 $KCODE = 'e'
 
 class DictFormatSkkdic < DictFormat
-  def initialize
-    super
+  def initialize (is_interactive = true)
+    super(is_interactive)
     @default_pos  = nil
     @default_freq = 0
     @default_attr = nil
