@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.2.2.2 2003/12/29 09:50:35 komatsu Exp $
+# $Id: prime.rb,v 1.2.2.7 2004/01/15 01:31:52 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -13,24 +13,24 @@ require 'prime/prime-config'
 require 'prime/taiyaki'
 require 'suikyo/suikyo'
 
+PRIME_CONFIGFILE_GLOBAL = File::join2(PRIME_CONFIG_DIR,  "Custom_prime.rb")
+PRIME_CONFIGFILE_LOCAL  = (ENV['PRIME_CONFIG'] or 
+                             File::join2(PRIME_USER_DIR, "Custom_prime.rb"))
+
 class Prime
   include Debug
 
   def initialize (engine_files = nil)
     @debug_mode = false
     Dir::ensure(PRIME_USER_DIR)
-    initialize_rc
+    initialize_rc()
 
-    @input = PrimeInput.new
+    @input = PrimeInput.new()
     @engines = init_engines(engine_files)
   end
 
   def initialize_rc
-    global_config_file = File::join2(PRIME_CONFIG_DIR, 'Custom_prime.rb')
-    local_config_file  =
-      (ENV['PRIME_CONFIG'] or File::join2(PRIME_USER_DIR, 'Custom_prime.rb'))
-
-    if File::exist?(global_config_file) == false then
+    if File::exist?(PRIME_CONFIGFILE_GLOBAL) == false then
       $stderr.puts "PRIME-ERROR:"
       $stderr.puts "  The file Custom_prime.rb is not found."
       $stderr.puts "  You might need to install Custom_prime.rb by"
@@ -38,12 +38,12 @@ class Prime
       Kernel::exit()
     end
 
-    load(global_config_file)
-    if FileTest::exist?(local_config_file) then
-      load(local_config_file)
+    load(PRIME_CONFIGFILE_GLOBAL)
+    if FileTest::exist?(PRIME_CONFIGFILE_LOCAL) then
+      load(PRIME_CONFIGFILE_LOCAL)
     else
-      Dir::ensure(File::dirname(local_config_file))
-      `cp #{global_config_file} #{local_config_file}`
+      Dir::ensure(File::dirname(PRIME_CONFIGFILE_LOCAL))
+      `cp #{PRIME_CONFIGFILE_GLOBAL} #{PRIME_CONFIGFILE_LOCAL}`
     end
   end
 
@@ -85,6 +85,12 @@ class Prime
     @engines.command(:close)
   end
 
+  def refresh
+    initialize_rc()
+    @input = PrimeInput.new()
+    @engines.command(:refresh)
+  end
+
   def get_env (key)
     return PRIME_ENV[key]
   end
@@ -93,25 +99,31 @@ class Prime
     return @input.label(pattern)
   end
 
+  def preedit_convert_input (pattern)
+    return @input.convert_input(pattern).join("\t")
+  end
+
   def set_context (context)
     @input.set_context(context)
   end
 
-  def learn_word (key, value, part = nil,
+  def learn_word (pron, literal, pos = nil,
 		  context = nil, suffix = nil, rest = nil)
-    part    = (part    or "")
+    pos     = (pos     or "")
     context = (context or "")
     suffix  = (suffix  or "")
     rest    = (rest    or "")
-    @engines.command(:learn_word, key, value, part, context, suffix, rest)
+    @engines.command(:learn_word, pron, literal, pos, context, suffix, rest)
   end
 
   def lookup_prefix (pattern)
-    lookup_internal(pattern, :lookup_prefix)
+    results = lookup_internal(pattern, :lookup_prefix)
+    return results
   end
 
   def lookup_exact (pattern)
-    lookup_internal(pattern, :lookup_exact)
+    results = lookup_internal(pattern, :lookup_exact)
+    return results
   end
 
   def lookup_hybrid (pattern)
@@ -124,6 +136,16 @@ class Prime
 #    return result.to_text
   end
 
+  def lookup_expansion (pattern)
+    results = lookup_internal(pattern, :lookup_expansion)
+    return results
+  end
+
+  def lookup_mixed (pattern)
+    results = lookup_internal(pattern, :lookup_mixed)
+    return results
+  end
+
   def check_existence (pron, pos, literal)
     pattern = [pron, pos, literal].join("\t")
     result = lookup_internal(pattern, :lookup_exact)
@@ -131,11 +153,6 @@ class Prime
   end
 
   private
-#   def lookup (pattern, method = :lookup_prefix)
-#     result = lookup_internal(pattern, method)
-#     return result.to_text
-#   end
-
   def lookup_internal (pattern, method = :lookup_prefix)
     @input.set(pattern)
     results = @engines.command(method, @input)
@@ -153,7 +170,13 @@ class PrimeInput
   end
 
   def initialize_suikyo
-    threshold_time = PRIME_ENV['suikyo_use_cache'] ? nil : Time.new
+    if PRIME_ENV['suikyo_use_cache'] then
+      threshold_time = [File::mtime(File::expand_path(__FILE__)),
+                        File::mtime(PRIME_CONFIGFILE_GLOBAL),
+                        File::mtime(PRIME_CONFIGFILE_LOCAL)].max
+    else
+      threshold_time = Time.new()
+    end
     suikyo = Marshal::init_file(File::join2(PRIME_USER_DIR, "suikyo.rbo"),
 				threshold_time) {
       suikyo = Suikyo.new
@@ -175,6 +198,11 @@ class PrimeInput
     end    
   end
 
+  def convert_input (string)
+    (conversion, pending, node) = @suikyo.convert_internal(string)
+    return [conversion, pending]
+  end
+
   def set (input, context = nil)
     @original = input
     (@base, @expands) = @suikyo.expand(input)
